@@ -10,16 +10,19 @@ from __future__ import annotations
 
 import asyncio
 import logging
+import time
+import warnings
 
 from typing import Any, Callable, List, Optional
 
 from clu.base import BaseClient
 from clu.command import Command, CommandStatus
+from clu.exceptions import CluWarning
 from clu.model import BaseModel, Property
 from clu.protocol import ReconnectingTCPClientProtocol
 
 from .types.keys import Key, KeysDictionary
-from .types.messages import Keyword
+from .types.messages import Keyword, Reply
 from .types.parser import ParseError, ReplyParser
 
 
@@ -106,24 +109,29 @@ class TronModel(BaseModel[TronKey]):
 
         for reply_key in reply.keywords:
 
+            self.last_seen = time.time()
+
             key_name = reply_key.name.lower()
             if key_name not in self.keydict:
-                raise ParseError(
-                    f"Cannot parse unknown keyword {self.name}.{reply_key.name}."
+                warnings.warn(
+                    f"Cannot parse unknown keyword {self.name}.{reply_key.name}.",
+                    CluWarning,
                 )
+                continue
 
             # When parsed the values in reply_key are string. After consuming
             # it with the Key, the values become typed values.
             result = self.keydict.keys[key_name].consume(reply_key)
 
             if not result:
-                raise ParseError(
-                    f"Failed parsing keyword {self.name}.{reply_key.name}."
+                warnings.warn(
+                    f"Failed parsing keyword {self.name}.{reply_key.name}.",
+                    CluWarning,
                 )
 
             self[key_name].update_keyword(reply_key)
 
-            self.notify(self, self[key_name])
+            self.notify(self, self[key_name].copy())
 
 
 class TronLoggingFilter(logging.Filter):
@@ -240,7 +248,14 @@ class TronConnection(BaseClient):
             if self.transport.is_closing():
                 return
 
-    def send_command(self, target, command_string, commander="tron.tron", mid=None):
+    def send_command(
+        self,
+        target,
+        command_string,
+        commander="tron.tron",
+        mid=None,
+        callback: Optional[Callable[[Reply], None]] = None,
+    ):
         """Sends a command through the hub.
 
         Parameters
@@ -259,6 +274,9 @@ class TronConnection(BaseClient):
             The message id. If `None`, a sequentially increasing value will
             be used. You should not specify a ``mid`` unless you really know
             what you're doing.
+        callback
+            A callback to invoke with each reply received from the actor.
+
         """
 
         mid = mid or self._mid
@@ -269,8 +287,11 @@ class TronConnection(BaseClient):
 
         command_string = f"{commander} {mid} {target} {command_string}\n"
 
-        command = Command(command_string=command_string)
-        command.set_status("RUNNING")
+        command: Command[TronConnection] = Command(
+            command_string=command_string,
+            reply_callback=callback,
+        )
+        # command.set_status("RUNNING")
         self.running_commands[mid] = command
 
         self.transport.write(command_string.encode())
@@ -344,5 +365,7 @@ class TronConnection(BaseClient):
             if mid in self.running_commands:
                 self.running_commands[mid].replies.append(reply)
                 self.running_commands[mid].set_status(status)
+                if self.running_commands[mid]._reply_callback is not None:
+                    self.running_commands[mid]._reply_callback(reply)
                 if status.is_done:
                     self.running_commands.pop(mid)
